type t = Contracted_shell_type.t


(** Returns the number of contracted Gaussians *)
val size : t -> int


(** Returns the i-th exponent *)
val expo : t -> int -> float


(** Returns the i-th contraction coefficient *)
val coef : t -> int -> float


(** Point on which all the Gaussians are centered *)
val center : t -> Coordinate.t


(** Total angular momentum *)
val totAngMom : t -> Angular_momentum.t


(** Normalization coefficient of the class corresponding to the i-th contraction *)
val norm_coef : t -> int -> float


(** Inside a class, the norm is the norm of the function with (totAngMom,0,0) *. 
    this scaling factor *)
val norm_coef_scale : t -> float array


(** The index in the array of contracted shells *)
val index  : t -> int


(** Returns a copy of the contracted shell with a modified index *)
val with_index  : t -> int -> t


(** The array of Zkeys corresponding to the powers of (x,y,z) in the class *)
val powers : t -> Zkey.t array


(** Pretty-printing of the contracted shell in a string *)
val to_string : t -> string

(** Creates a contracted shell *)
val make :
  index:int ->
  expo:float array ->
  coef:float array ->
  center:Coordinate.t -> totAngMom:Angular_momentum.t -> t


